=== modified file 'INSTALL'
--- INSTALL	2010-03-06 14:34:50 +0000
+++ INSTALL	2010-03-06 15:28:20 +0000
@@ -30,3 +30,8 @@
 
  git clone git://software.jaos.org/var/cache/git/slapt-get
 
+- Cross compiling (for armedslack):
+
+  $ CFLAGS="--sysroot=/usr/arm-iZum-linux" crossmake
+
+crossmake must be defined like for linux kernel

=== modified file 'Makefile'
--- Makefile	2010-03-06 14:34:50 +0000
+++ Makefile	2010-03-06 15:28:20 +0000
@@ -1,9 +1,12 @@
 PACKAGE=slapt-get
 VERSION=0.10.2c
-ARCH=$(shell uname -m | sed -e "s/i[3456]86/i386/")
+ifndef $(ARCH)
+	ARCH=$(shell uname -m | sed -e "s/i[3456]86/i386/")
+endif
 LIBDIR=/usr/lib
 RELEASE=1
-CC=gcc
+CC=$(CROSS_COMPILE)gcc
+STRIP=$(CROSS_COMPILE)strip
 CURLFLAGS=`curl-config --libs`
 OBJS=src/common.o src/configuration.o src/package.o src/curl.o src/transaction.o src/action.o src/main.o
 LIBOBJS=src/common.o src/configuration.o src/package.o src/curl.o src/transaction.o
@@ -24,10 +27,14 @@
 	LIBHEADERS+=src/gpgme.h
 	LDFLAGS+=`gpgme-config --libs`
 endif
-CFLAGS=-W -Werror -Wall -O2 -ansi -pedantic $(DEFINES) -fpic
+
 ifeq ($(ARCH),x86_64)
 	LIBDIR=/usr/lib64
 	CFLAGS=-W -Werror -Wall -O2 -ansi -pedantic $(DEFINES) -fPIC
+else ifeq ($(ARCH),arm)
+	CFLAGS:=-W -Werror -Wall -O2 -ansi -pedantic $(DEFINES) -fpic $(CFLAGS)
+else
+	CFLAGS:=-W -Werror -Wall -O2 -ansi -pedantic $(DEFINES) -fpic $(CFLAGS)
 endif
 
 default: $(PACKAGE)
@@ -61,7 +68,7 @@
 	cd $(DESTDIR)$(LIBDIR); ln -s libslapt.so.$(VERSION) libslapt.so
 
 doinstall: libsinstall
-	strip --strip-unneeded $(PACKAGE)
+	$(STRIP) --strip-unneeded $(PACKAGE)
 	if [ ! -d $(DESTDIR)$(SBINDIR) ]; then mkdir -p $(DESTDIR)$(SBINDIR);fi
 	install $(PACKAGE) $(DESTDIR)$(SBINDIR)
 	-chown $$(stat --format "%u:%g" /usr/sbin) $(DESTDIR)$(SBINDIR)$(PACKAGE)
@@ -134,7 +141,7 @@
 	cp $(PACKAGE) ./pkg/$(SBINDIR)
 	-chown $$(stat --format "%u:%g" /usr/sbin) ./pkg/$(SBINDIR)
 	-chown $$(stat --format "%u:%g" /usr/sbin) ./pkg/$(SBINDIR)/$(PACKAGE)
-	strip ./pkg/$(SBINDIR)/$(PACKAGE)
+	$(STRIP) ./pkg/$(SBINDIR)/$(PACKAGE)
 	cp $(RCSOURCE) pkg/etc/slapt-get/slapt-getrc.new
 	mkdir -p ./pkg/usr/doc/$(PACKAGE)-$(VERSION)/
 	cp default.slapt-getrc.* example.slapt-getrc.* COPYING ChangeLog INSTALL README FAQ FAQ.html TODO ./pkg/usr/doc/$(PACKAGE)-$(VERSION)/
@@ -154,7 +161,7 @@
 	mkdir -p pkg/usr/include
 	cp src/slapt.h pkg/usr/include/
 	cp src/libslapt.a src/libslapt.so.$(VERSION) pkg$(LIBDIR)/
-	strip pkg$(LIBDIR)/libslapt.so.$(VERSION)
+	$(STRIP) pkg$(LIBDIR)/libslapt.so.$(VERSION)
 	( cd pkg$(LIBDIR); ln -s libslapt.so.$(VERSION) libslapt.so )
 	-( cd pkg; /sbin/makepkg -l y -c n ../$(PACKAGE)-$(VERSION)-$(ARCH)-$(RELEASE).tgz )
 

=== modified file 'README'
--- README	2010-03-06 14:34:50 +0000
+++ README	2010-03-06 15:28:20 +0000
@@ -261,3 +261,5 @@
    Anders F Bjorklund <afb at users dot sourceforge dot net> contributed the
    slapt_get_pkg_filelist() support.
 
+   Vitaly Chernookiy <vitaly.v.ch at gmail dot com> contribute crosscompiling
+   support

=== added file 'default.slapt-getrc.arm'
--- default.slapt-getrc.arm	1970-01-01 00:00:00 +0000
+++ default.slapt-getrc.arm	2010-03-06 15:28:20 +0000
@@ -0,0 +1,25 @@
+# Working directory for local storage/cache.
+WORKINGDIR=/var/slapt-get
+
+# Exclude package names and expressions.
+# To exclude pre and beta packages, add this to the exclude: 
+#   [0-9\_\.\-]{1}pre[0-9\-\.\-]{1}
+EXCLUDE=^aaa_elflibs,^devs,^glibc-.*,^kernel-.*,^udev,.*-[0-9]+dl$,x86_64
+
+# Base url to directory with a PACKAGES.TXT.
+# This can point to any release, ie: 9.0, 10.0, current, etc.
+SOURCE=ftp://ftp.armedslack.org/armedslack/armedslack-current/:OFFICIAL
+
+# Sources for the testing, extra, and pasture areas - if you use them.
+# SOURCE=ftp://ftp.slackware.com/pub/slackware/slackware-13.0/extra/:PREFERRED
+# SOURCE=ftp://ftp.slackware.com/pub/slackware/slackware-13.0/testing/
+# SOURCE=ftp://ftp.slackware.com/pub/slackware/slackware-13.0/pasture/
+
+# Source for slapt-get.
+# SOURCE=http://software.jaos.org/slackpacks/13.0/:OFFICIAL
+
+# Packages on a CD/DVD.
+# SOURCE=file:///mnt/cdrom/:OFFICIAL
+
+# Home made packages.
+# SOURCE=file:///var/www/packages/:CUSTOM
